@@ -1,7 +1,7 @@
 /*****************************************************************************
  * decode_sdt.c: SDT decoder example
  *----------------------------------------------------------------------------
- * Copyright (C) 2001-2010 VideoLAN
+ * Copyright (C) 2001-2011 VideoLAN
  * $Id: decode_sdt.c,v 1.1 2002/12/11 13:04:56 jobi Exp $
  *
  * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -25,11 +25,11 @@
  *
  *****************************************************************************/
 
-
 #include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdbool.h>
 #include <unistd.h>
 #include <fcntl.h>
 
@@ -54,11 +54,10 @@
 #include <dvbpsi/sdt.h>
 #endif
 
-
 /*****************************************************************************
  * ReadPacket
  *****************************************************************************/
-static int ReadPacket(int i_fd, uint8_t* p_dst)
+static bool ReadPacket(int i_fd, uint8_t* p_dst)
 {
   int i = 187;
   int i_rc = 1;
@@ -77,7 +76,7 @@ static int ReadPacket(int i_fd, uint8_t* p_dst)
       i -= i_rc;
   }
 
-  return (i == 0) ? 1 : 0;
+  return (i == 0) ? true : false;
 }
 
 
@@ -107,7 +106,7 @@ static void DumpSDT(void* p_zero, dvbpsi_sdt_t* p_sdt)
   printf(  "\n");
   printf(  "New active SDT\n");
   printf(  "  ts_id : %d\n",
-         p_sdt->i_ts_id);
+         p_sdt->i_extension);
   printf(  "  version_number : %d\n",
          p_sdt->i_version);
   printf(  "  network_id        : %d\n",
@@ -120,18 +119,35 @@ static void DumpSDT(void* p_zero, dvbpsi_sdt_t* p_sdt)
     DumpDescriptors("    |  ]", p_service->p_first_descriptor);
     p_service = p_service->p_next;
   }
-  dvbpsi_DeleteSDT(p_sdt);
+  dvbpsi_sdt_delete(p_sdt);
+}
+
+/*****************************************************************************
+ * DVBPSI messaging callback
+ *****************************************************************************/
+static void message(dvbpsi_t *handle, const dvbpsi_msg_level_t level, const char* msg)
+{
+    switch(level)
+    {
+        case DVBPSI_MSG_ERROR: fprintf(stderr, "Error: "); break;
+        case DVBPSI_MSG_WARN:  fprintf(stderr, "Warning: "); break;
+        case DVBPSI_MSG_DEBUG: fprintf(stderr, "Debug: "); break;
+        default: /* do nothing */
+            return;
+    }
+    fprintf(stderr, "%s\n", msg);
 }
 
 /*****************************************************************************
  * NewSubtable
  *****************************************************************************/
-static void NewSubtable(void * p_zero, dvbpsi_handle h_dvbpsi,
-                 uint8_t i_table_id, uint16_t i_extension)
+static void NewSubtable(dvbpsi_t *p_dvbpsi, uint8_t i_table_id, uint16_t i_extension,
+                        void * p_zero)
 {
   if(i_table_id == 0x42)
   {
-    dvbpsi_AttachSDT(h_dvbpsi, i_table_id, i_extension, DumpSDT, NULL);
+     if (!dvbpsi_sdt_attach(p_dvbpsi, i_table_id, i_extension, DumpSDT, NULL))
+         fprintf(stderr, "Failed to attach SDT subdecoder\n");
   }
 }
 
@@ -142,15 +158,22 @@ int main(int i_argc, char* pa_argv[])
 {
   int i_fd;
   uint8_t data[188];
-  dvbpsi_handle h_dvbpsi;
-  int b_ok;
+  dvbpsi_t *p_dvbpsi;
+  bool b_ok;
 
   if(i_argc != 2)
     return 1;
 
   i_fd = open(pa_argv[1], 0);
+  if (i_fd < 0)
+      return 1;
 
-  h_dvbpsi = dvbpsi_AttachDemux(NewSubtable, NULL);
+  p_dvbpsi = dvbpsi_new(&message, DVBPSI_MSG_DEBUG);
+  if (p_dvbpsi == NULL)
+      goto out;
+
+  if (!dvbpsi_AttachDemux(p_dvbpsi, NewSubtable, NULL))
+      goto out;
 
   b_ok = ReadPacket(i_fd, data);
 
@@ -158,12 +181,17 @@ int main(int i_argc, char* pa_argv[])
   {
     uint16_t i_pid = ((uint16_t)(data[1] & 0x1f) << 8) + data[2];
     if(i_pid == 0x11)
-      dvbpsi_PushPacket(h_dvbpsi, data);
+      dvbpsi_packet_push(p_dvbpsi, data);
     b_ok = ReadPacket(i_fd, data);
   }
 
-  dvbpsi_DetachDemux(h_dvbpsi);
-
+out:
+  if (p_dvbpsi)
+  {
+    dvbpsi_DetachDemux(p_dvbpsi);
+    dvbpsi_delete(p_dvbpsi);
+  }
+  close(i_fd);
   return 0;
 }
 
