@@ -80,7 +80,7 @@ int tcp_close(int fd)
 {
     int result = 0;
 
-    result = shutdown(fd, 2);
+    result = shutdown(fd, SHUT_RDWR);
     if (result < 0)
         perror("tcp shutdown error");
     return result;
@@ -126,7 +126,7 @@ int tcp_open(const char *ipaddress, int port)
         sflags = SOCK_CLOEXEC;
 #endif
         s_ctl = socket(ptr->ai_family, ptr->ai_socktype | sflags, ptr->ai_protocol);
-        if (s_ctl <= 0)
+        if (s_ctl < 0)
         {
             perror("tcp socket error");
             continue;
@@ -136,19 +136,24 @@ int tcp_open(const char *ipaddress, int port)
         if (!set_fdsocketclosexec(s_ctl))
         {
             close(s_ctl);
+            s_ctl = -1;
             continue;
         }
 #endif
 
-        setsockopt (s_ctl, SOL_SOCKET, SO_REUSEADDR, &(int){ 1 }, sizeof (int));
+        if (setsockopt (s_ctl, SOL_SOCKET, SO_REUSEADDR, &(int){ 1 }, sizeof (int)) < 0)
+            perror("tcp setsockopt error");
 
         result = connect( s_ctl, ptr->ai_addr, ptr->ai_addrlen );
         if (result < 0)
         {
             close(s_ctl);
+            s_ctl = -1;
             perror( "tcp connect error" );
             continue;
         }
+
+        break; /* success */
     }
 
     freeaddrinfo(addr);
