@@ -1,24 +1,24 @@
 /*****************************************************************************
  * gen_pat.c: PAT generator
  *----------------------------------------------------------------------------
- * (c)2001-2002 VideoLAN
- * $Id: gen_pat.c 178 2008-07-14 09:03:13Z sam $
+ * Copyright (C) 2001-2011 VideoLAN
+ * $Id: gen_pat.c,v 1.3 2002/10/07 14:15:14 sam Exp $
  *
  * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *----------------------------------------------------------------------------
  *
@@ -28,6 +28,7 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <stdbool.h>
 
 #if defined(HAVE_INTTYPES_H)
 #include <inttypes.h>
@@ -46,7 +47,6 @@
 #include <dvbpsi/pat.h>
 #endif
 
-
 /*****************************************************************************
  * writePSI
  *****************************************************************************/
@@ -56,6 +56,7 @@ static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
 
   while(p_section)
   {
+    size_t i_bytes_written = 0;
     uint8_t* p_pos_in_ts;
     uint8_t* p_byte = p_section->p_data;
     uint8_t* p_end =   p_section->p_payload_end
@@ -71,8 +72,12 @@ static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
       *(p_pos_in_ts++) = *(p_byte++);
     while(p_pos_in_ts < p_packet + 188)
       *(p_pos_in_ts++) = 0xff;
-    fwrite(p_packet, 1, 188, stdout);
-
+    i_bytes_written = fwrite(p_packet, 1, 188, stdout);
+    if(i_bytes_written == 0)
+    {
+      fprintf(stderr,"eof detected ... aborting\n");
+      return;
+    }
     p_packet[3] = (p_packet[3] + 1) & 0x0f;
 
     while(p_byte < p_end)
@@ -86,8 +91,12 @@ static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
         *(p_pos_in_ts++) = *(p_byte++);
       while(p_pos_in_ts < p_packet + 188)
         *(p_pos_in_ts++) = 0xff;
-      fwrite(p_packet, 1, 188, stdout);
-
+      i_bytes_written = fwrite(p_packet, 1, 188, stdout);
+      if(i_bytes_written == 0)
+      {
+        fprintf(stderr,"eof detected ... aborting\n");
+        return;
+      }
       p_packet[3] = (p_packet[3] + 1) & 0x0f;
     }
 
@@ -95,6 +104,18 @@ static void writePSI(uint8_t* p_packet, dvbpsi_psi_section_t* p_section)
   }
 }
 
+static void message(dvbpsi_t *handle, const dvbpsi_msg_level_t level, const char* msg)
+{
+    switch(level)
+    {
+        case DVBPSI_MSG_ERROR: fprintf(stderr, "Error: "); break;
+        case DVBPSI_MSG_WARN:  fprintf(stderr, "Warning: "); break;
+        case DVBPSI_MSG_DEBUG: fprintf(stderr, "Debug: "); break;
+        default: /* do nothing */
+            return;
+    }
+    fprintf(stderr, "%s\n", msg);
+}
 
 /*****************************************************************************
  * main
@@ -108,32 +129,36 @@ int main(int i_argc, char* pa_argv[])
   dvbpsi_psi_section_t* p_section5, * p_section6;
   int i;
 
-  /* PAT generation */
-  dvbpsi_InitPAT(&pat, 1, 0, 0);
-  dvbpsi_PATAddProgram(&pat, 0, 0x12);
-  dvbpsi_PATAddProgram(&pat, 1, 0x42);
-  dvbpsi_PATAddProgram(&pat, 2, 0x21);
-  dvbpsi_PATAddProgram(&pat, 3, 0x24);
-  for(i = 4; i < 43; i++)
-    dvbpsi_PATAddProgram(&pat, i, i);
+  dvbpsi_t *p_dvbpsi = dvbpsi_new(&message, DVBPSI_MSG_DEBUG);
+  if (p_dvbpsi == NULL)
+      return 1;
 
-  p_section1 = dvbpsi_GenPATSections(&pat, 4);
+  /* PAT generation */
+  dvbpsi_pat_init(&pat, 1, 0, 0);
+  dvbpsi_pat_program_add(&pat, 0, 0x12);
+  dvbpsi_pat_program_add(&pat, 1, 0x42);
+  dvbpsi_pat_program_add(&pat, 2, 0x21);
+  dvbpsi_pat_program_add(&pat, 3, 0x24);
+  for(i = 4; i < 43; i++)
+    dvbpsi_pat_program_add(&pat, i, i);
+
+  p_section1 = dvbpsi_pat_sections_generate(p_dvbpsi, &pat, 4);
   pat.b_current_next = 1;
-  p_section2 = dvbpsi_GenPATSections(&pat, 8);
+  p_section2 = dvbpsi_pat_sections_generate(p_dvbpsi, &pat, 8);
 
   pat.i_version = 1;
 
   pat.b_current_next = 0;
-  p_section3 = dvbpsi_GenPATSections(&pat, 16);
+  p_section3 = dvbpsi_pat_sections_generate(p_dvbpsi, &pat, 16);
   pat.b_current_next = 1;
-  p_section4 = dvbpsi_GenPATSections(&pat, 300);
+  p_section4 = dvbpsi_pat_sections_generate(p_dvbpsi, &pat, 300);
 
   pat.i_version = 2;
 
   pat.b_current_next = 0;
-  p_section5 = dvbpsi_GenPATSections(&pat, 16);
+  p_section5 = dvbpsi_pat_sections_generate(p_dvbpsi, &pat, 16);
   pat.b_current_next = 1;
-  p_section6 = dvbpsi_GenPATSections(&pat, 16);
+  p_section6 = dvbpsi_pat_sections_generate(p_dvbpsi, &pat, 16);
 
   /* TS packets generation */
   packet[0] = 0x47;
@@ -147,7 +172,6 @@ int main(int i_argc, char* pa_argv[])
   writePSI(packet, p_section5);
   writePSI(packet, p_section6);
 
-
   dvbpsi_DeletePSISections(p_section1);
   dvbpsi_DeletePSISections(p_section2);
   dvbpsi_DeletePSISections(p_section3);
@@ -155,8 +179,9 @@ int main(int i_argc, char* pa_argv[])
   dvbpsi_DeletePSISections(p_section5);
   dvbpsi_DeletePSISections(p_section6);
 
-  dvbpsi_EmptyPAT(&pat);
+  dvbpsi_pat_empty(&pat);
 
+  dvbpsi_delete(p_dvbpsi);
   return 0;
 }
 
