@@ -318,8 +318,9 @@ static bool dvbpsi_CheckEIT(dvbpsi_t *p_dvbpsi, dvbpsi_eit_decoder_t *p_eit_deco
     {
         /* last_section_number */
         dvbpsi_error(p_dvbpsi, "EIT decoder",
-                     "'last_section_number' differs"
-                     " whereas no discontinuity has occured");
+                     "'last_section_number' differs %2d / %2d "
+                     " whereas no discontinuity has occurred",
+                     p_eit_decoder->i_last_section_number, p_section->i_last_number);
         b_reinit = true;
     }
 
@@ -405,7 +406,6 @@ static bool dvbpsi_AddSectionEIT(dvbpsi_t *p_dvbpsi, dvbpsi_eit_decoder_t *p_eit
 
         if (p_eit_decoder->p_building_eit == NULL)
             return false;
-        p_eit_decoder->i_last_section_number = p_section->i_last_number;
     }
 
     /* Add to linked list of sections */
