@@ -62,17 +62,6 @@ void dvbpsi_sdt_sections_gather(dvbpsi_t *p_dvbpsi,
 void dvbpsi_sdt_sections_decode(dvbpsi_sdt_t* p_sdt,
                                 dvbpsi_psi_section_t* p_section);
 
-/*****************************************************************************
- * Deprecated API's
- *****************************************************************************/
-__attribute__((deprecated))
-void dvbpsi_GatherSDTSections(dvbpsi_handle *p_dvbpsi,
-                              dvbpsi_decoder_t *p_private_decoder,
-                              dvbpsi_psi_section_t *p_section);
-__attribute__((deprecated))
-void dvbpsi_DecodeSDTSections(dvbpsi_sdt_t* p_sdt,
-                              dvbpsi_psi_section_t* p_section);
-
 #else
 #error "Multiple inclusions of sdt_private.h"
 #endif
