@@ -1,7 +1,7 @@
 /*****************************************************************************
  * sis_private.h: private SIS structures
  *----------------------------------------------------------------------------
- * Copyright (c) 2011 VideoLAN
+ * Copyright (c) 2010-2011 VideoLAN
  * $Id$
  *
  * Authors: Jean-Paul Saman <jpsaman@videolan.org>
@@ -34,40 +34,34 @@
  *****************************************************************************/
 typedef struct dvbpsi_sis_decoder_s
 {
-  dvbpsi_sis_callback           pf_callback;
-  void *                        p_cb_data;
+    DVBPSI_DECODER_COMMON
 
-  /* */
-  dvbpsi_sis_t                  *current_sis;
-  dvbpsi_sis_t                  *p_building_sis;
+    dvbpsi_sis_callback           pf_sis_callback;
+    void *                        p_cb_data;
 
-  int                           b_current_valid;
+    /* */
+    dvbpsi_sis_t                  current_sis;
+    dvbpsi_sis_t                  *p_building_sis;
 
 } dvbpsi_sis_decoder_t;
 
-
 /*****************************************************************************
- * dvbpsi_GatherSISSections
+ * dvbpsi_sis_sections_gather
  *****************************************************************************
  * Callback for the PSI decoder.
  *****************************************************************************/
-__attribute__((deprecated))
-void dvbpsi_GatherSISSections(dvbpsi_decoder_t* p_psi_decoder,
-                              void* p_private_decoder,
+void dvbpsi_sis_sections_gather(dvbpsi_t* p_dvbpsi,
+                              dvbpsi_decoder_t * p_decoder,
                               dvbpsi_psi_section_t* p_section);
 
-
 /*****************************************************************************
- * dvbpsi_DecodeSISSection
+ * dvbpsi_sis_sections_decode
  *****************************************************************************
  * SIS decoder.
  *****************************************************************************/
-__attribute__((deprecated))
-void dvbpsi_DecodeSISSections(dvbpsi_sis_t* p_sis,
-                              dvbpsi_psi_section_t* p_section);
-
+void dvbpsi_sis_sections_decode(dvbpsi_t* p_dvbpsi, dvbpsi_sis_t* p_sis,
+                               dvbpsi_psi_section_t* p_section);
 
 #else
 #error "Multiple inclusions of sis_private.h"
 #endif
-
